@@ -1,12 +1,12 @@
-<?PHP // $Id: edit.php,v 1.14 2005/05/31 18:44:03 skodak Exp $
+<?PHP // $Id: edit.php,v 1.15 2005/07/14 20:58:07 skodak Exp $
 
 require_once('../../config.php');
 require_once('lib.php');
 
-require_variable($id);             // Course Module ID
-optional_variable($chapterid, 0);  // Chapter ID
-optional_variable($pagenum, 0);    // Chapter order
-optional_variable($subchapter, 0); // create subchapter
+$id         = required_param('id', PARAM_INT);           // Course Module ID
+$chapterid  = optional_param('chapterid', 0, PARAM_INT); // Chapter ID
+$pagenum    = optional_param('pagenum', 0, PARAM_INT);
+$subchapter = optional_param('subchapter', 0, PARAM_BOOL);
 
 // =========================================================================
 // security checks START - only teachers edit
@@ -42,7 +42,6 @@ if ($chapter) {
 } else {
     $pagenum = (integer)$pagenum;
 }
-$subchapter = ($subchapter) ? 1 : 0;
 
 // =========================================================================
 // security checks END
