@@ -1,12 +1,11 @@
-<?PHP // $Id: import.php,v 1.15 2005/05/31 18:44:03 skodak Exp $
+<?PHP // $Id: import.php,v 1.16 2005/07/14 20:58:08 skodak Exp $
 
 require_once('../../config.php');
 require_once('lib.php');
-require_once("$CFG->dirroot/version.php");
 
-require_variable($id);             // Course Module ID
-optional_variable($subchapter);    // Import as subchapters
-//$cancel - evaluated later using isset()
+$id         = required_param('id', PARAM_INT);           // Course Module ID
+$subchapter = optional_param('subchapter', 0, PARAM_BOOL);
+$cancel     = optional_param('cancel', 0, PARAM_BOOL);
 
 // =========================================================================
 // security checks START - only teachers edit
@@ -31,14 +30,13 @@ if (!$book = get_record('book', 'id', $cm->instance)) {
 
 //check all variables
 unset($id);
-$subchapter = ($subchapter) ? 1 : 0;
 
 // =========================================================================
 // security checks END
 // =========================================================================
 
 ///cancel pressed, go back to book
-if (isset($cancel)) {
+if ($cancel) {
     redirect('view.php?id='.$cm->id);
     die;
 }
@@ -148,13 +146,8 @@ if (($form = data_submitted()) && (confirm_sesskey())) {
         <td>
             <?php
               echo '<input name="reference" size="40" value="" />&nbsp;';
-              if ($version >= 2004083123) {
-                  button_to_popup_window ('/files/index.php?choose=theform.reference&id='.$course->id,
-                                          'coursefiles', $strchoose, 500, 750, $strchoose);
-              } else {
-                  button_to_popup_window ('/mod/book/coursefiles.php?id='.$course->id,
-                                          'coursefiles', $strchoose, 500, 750, $strchoose);
-              }
+              button_to_popup_window ('/mod/book/coursefiles.php?choose=theform.reference&id='.$course->id,
+                                      'coursefiles', $strchoose, 500, 750, $strchoose);
             ?>
         </td>
     </tr>
