@@ -1,10 +1,10 @@
-<?PHP // $Id: print.php,v 1.16 2005/04/04 07:15:50 skodak Exp $
+<?PHP // $Id: print.php,v 1.17 2005/07/14 20:58:08 skodak Exp $
 
 require_once('../../config.php');
 require_once('lib.php');
 
-require_variable($id);            // Course Module ID
-optional_variable($chapterid, 0); // Chapter ID
+$id        = required_param('id', PARAM_INT);           // Course Module ID
+$chapterid = optional_param('chapterid', 0, PARAM_INT); // Chapter ID
 
 // =========================================================================
 // security checks START - teachers and students view
