@@ -1,4 +1,4 @@
-<?PHP // $Id: restorelib.php,v 1.3 2004/10/14 20:05:11 skodak Exp $
+<?PHP // $Id: restorelib.php,v 1.4 2005/07/14 20:58:08 skodak Exp $
     //This php script contains all the stuff to backup/restore
     //book mods
 
@@ -292,198 +292,71 @@
     //working in the backup/restore process. It's called from restore_decode_content_links()
     //function in restore process
     function book_decode_content_links_caller($restore) {
-
         global $CFG;
-
         $status = true;
 
-        echo "<ul>";
-
-        //FORUM: Decode every POST (message) in the coure
-
-        //Check we are restoring forums
-        if ($restore->mods['forum']->restore == 1) {
-            echo "<li>".get_string("from")." ".get_string("modulenameplural","forum");
-            //Get all course posts
-            if ($posts = get_records_sql ("SELECT p.id, p.message
-                                       FROM {$CFG->prefix}forum_posts p,
-                                            {$CFG->prefix}forum_discussions d
-                                       WHERE d.course = $restore->course_id AND
-                                             p.discussion = d.id")) {
-                //Iterate over each post->message
-                $i = 0;   //Counter to send some output to the browser to avoid timeouts
-                foreach ($posts as $post) {
-                    //Increment counter
-                    $i++;
-                    $content = $post->message;
-                    $result = book_decode_content_links($content,$restore);
-                    if ($result != $content) {
-                        //Update record
-                        $post->message = addslashes($result);
-                        $status = update_record("forum_posts",$post);
-                        if ($CFG->debug>7) {
-                            echo "<br><hr>".$content."<br>changed to</br>".$result."<hr><br>";
-                        }
+        //Decode every BOOK (summary) in the coure
+        if ($books = get_records_sql ("SELECT b.id, b.summary
+                                   FROM {$CFG->prefix}book b
+                                   WHERE b.course = $restore->course_id")) {
+            //Iterate over each book->summary
+            $i = 0;   //Counter to send some output to the browser to avoid timeouts
+            foreach ($books as $book) {
+                //Increment counter
+                $i++;
+                $content = $book->summary;
+                $result = restore_decode_content_links_worker($content,$restore);
+                if ($result != $content) {
+                    //Update record
+                    $book->summary = addslashes($result);
+                    $status = update_record('book',$book);
+                    if ($CFG->debug>7) {
+                        echo '<br /><hr />'.htmlentities($content).'<br />changed to<br />'.htmlentities($result).'<hr /><br />';
                     }
-                    //Do some output
-                    if (($i+1) % 5 == 0) {
-                        echo ".";
-                        if (($i+1) % 100 == 0) {
-                            echo "<br>";
-                        }
-                        backup_flush(300);
+                }
+                //Do some output
+                if (($i+1) % 5 == 0) {
+                    echo '.';
+                    if (($i+1) % 100 == 0) {
+                        echo '<br />';
                     }
+                    backup_flush(300);
                 }
             }
         }
 
-        //FORUM: Decode every FORUM (intro) in the coure
-
-        //Check we are restoring forums
-        if ($restore->mods['forum']->restore == 1) {
-            //Get all course forums
-            if ($forums = get_records_sql ("SELECT f.id, f.intro
-                                       FROM {$CFG->prefix}forum f
-                                       WHERE f.course = $restore->course_id")) {
-                //Iterate over each forum->intro
-                $i = 0;   //Counter to send some output to the browser to avoid timeouts
-                foreach ($forums as $forum) {
-                    //Increment counter
-                    $i++;
-                    $content = $forum->intro;
-                    $result = book_decode_content_links($content,$restore);
-                    if ($result != $content) {
-                        //Update record
-                        $forum->intro = addslashes($result);
-                        $status = update_record("forum",$forum);
-                        if ($CFG->debug>7) {
-                            echo "<br><hr>".$content."<br>changed to</br>".$result."<hr><br>";
-                        }
+        //Decode every CHAPTER in the course
+        if ($chapters = get_records_sql ("SELECT ch.id, ch.content
+                                   FROM {$CFG->prefix}book b,
+                                        {$CFG->prefix}book_chapters ch
+                                   WHERE b.course = $restore->course_id AND
+                                         ch.bookid = b.id")) {
+            //Iterate over each chapter->content
+            $i = 0;   //Counter to send some output to the browser to avoid timeouts
+            foreach ($chapters as $chapter) {
+                //Increment counter
+                $i++;
+                $content = $chapter->content;
+                $result = restore_decode_content_links_worker($content,$restore);
+                if ($result != $content) {
+                    //Update record
+                    $chapter->content = addslashes($result);
+                    $status = update_record('book_chapters',$chapter);
+                    if ($CFG->debug>7) {
+                        echo '<br /><hr />'.htmlentities($content).'<br />changed to<br />'.htmlentities($result).'<hr /><br />';
                     }
-                    //Do some output
-                    if (($i+1) % 5 == 0) {
-                        echo ".";
-                        if (($i+1) % 100 == 0) {
-                            echo "<br>";
-                        }
-                        backup_flush(300);
+                }
+                //Do some output
+                if (($i+1) % 5 == 0) {
+                    echo '.';
+                    if (($i+1) % 100 == 0) {
+                        echo '<br />';
                     }
+                    backup_flush(300);
                 }
             }
         }
 
-        //RESOURCE: Decode every RESOURCE (alltext) in the coure
-
-        //Check we are restoring resources
-        if ($restore->mods['resource']->restore == 1) {
-            echo "<li>".get_string("from")." ".get_string("modulenameplural","resource");
-            //Get all course resources
-            if ($resources = get_records_sql ("SELECT r.id, r.alltext
-                                       FROM {$CFG->prefix}resource r
-                                       WHERE r.course = $restore->course_id")) {
-                //Iterate over each resource->alltext
-                $i = 0;   //Counter to send some output to the browser to avoid timeouts
-                foreach ($resources as $resource) {
-                    //Increment counter
-                    $i++;
-                    $content = $resource->alltext;
-                    $result = book_decode_content_links($content,$restore);
-                    if ($result != $content) {
-                        //Update record
-                        $resource->alltext = addslashes($result);
-                        $status = update_record("resource",$resource);
-                        if ($CFG->debug>7) {
-                            echo "<br><hr>".$content."<br>changed to</br>".$result."<hr><br>";
-                        }
-                    }
-                    //Do some output
-                    if (($i+1) % 5 == 0) {
-                        echo ".";
-                        if (($i+1) % 100 == 0) {
-                            echo "<br>";
-                        }
-                        backup_flush(300);
-                    }
-                }
-            }
-        }
-
-        //RESOURCE: Decode every RESOURCE (summary) in the coure
-
-        //Check we are restoring resources
-        if ($restore->mods['resource']->restore == 1) {
-            //Get all course resources
-            if ($resources = get_records_sql ("SELECT r.id, r.summary
-                                       FROM {$CFG->prefix}resource r
-                                       WHERE r.course = $restore->course_id")) {
-                //Iterate over each resource->summary
-                $i = 0;   //Counter to send some output to the browser to avoid timeouts
-                foreach ($resources as $resource) {
-                    //Increment counter
-                    $i++;
-                    $content = $resource->summary;
-                    $result = book_decode_content_links($content,$restore);
-                    if ($result != $content) {
-                        //Update record
-                        $resource->summary = addslashes($result);
-                        $status = update_record("resource",$resource);
-                        if ($CFG->debug>7) {
-                            echo "<br><hr>".$content."<br>changed to</br>".$result."<hr><br>";
-                        }
-                    }
-                    //Do some output
-                    if (($i+1) % 5 == 0) {
-                        echo ".";
-                        if (($i+1) % 100 == 0) {
-                            echo "<br>";
-                        }
-                        backup_flush(300);
-                    }
-                }
-            }
-        }
-
-        //BOOK: Decode every CHAPTER in the course
-
-        //Check we are restoring book
-        if ($restore->mods['book']->restore == 1) {
-            echo '<li>'.get_string('from').' '.get_string('modulenameplural','book');
-            //Get all course chapters
-            if ($chapters = get_records_sql ("SELECT ch.id, ch.content
-                                       FROM {$CFG->prefix}book b,
-                                            {$CFG->prefix}book_chapters ch
-                                       WHERE b.course = $restore->course_id AND
-                                             ch.bookid = b.id")) {
-                //Iterate over each chapter->content
-                $i = 0;   //Counter to send some output to the browser to avoid timeouts
-                foreach ($chapters as $chapter) {
-                    //Increment counter
-                    $i++;
-                    $content = $chapter->content;
-                    $result = book_decode_content_links($content,$restore);
-                    if ($result != $content) {
-                        //Update record
-                        $chapter->content = addslashes($result);
-                        $status = update_record('book_chapters',$chapter);
-                        if ($CFG->debug>7) {
-                            echo '<br><hr>'.$content.'<br>changed to</br>'.$result.'<hr><br>';
-                        }
-                    }
-                    //Do some output
-                    if (($i+1) % 5 == 0) {
-                        echo '.';
-                        if (($i+1) % 100 == 0) {
-                            echo '<br>';
-                        }
-                        backup_flush(300);
-                    }
-                }
-            }
-        }
-
-
-
-        echo '</ul>';
         return $status;
     }
 
