@@ -1,4 +1,4 @@
-<?PHP // $Id: teacheraccess.php,v 1.5 2004/11/15 22:01:05 skodak Exp $
+<?PHP // $Id: teacheraccess.php,v 1.6 2005/07/14 20:58:07 skodak Exp $
 
 ///standard routine to allow only teachers in
 ///check of $id and $chapterid parameters
@@ -6,8 +6,8 @@
 require_once('../../config.php');
 require_once('lib.php');
 
-require_variable($id);         // Course Module ID
-require_variable($chapterid);  // Chapter ID
+$id        = required_param('id', PARAM_INT);        // Course Module ID
+$chapterid = required_param('chapterid', PARAM_INT); // Chapter ID
 
 require_login();
 
