@@ -1,11 +1,11 @@
-<?PHP // $Id: view.php,v 1.15 2005/05/31 18:20:28 skodak Exp $
+<?PHP // $Id: view.php,v 1.16 2005/07/14 20:58:07 skodak Exp $
 
 require_once('../../config.php');
 require_once('lib.php');
 
-require_variable($id);             // Course Module ID
-optional_variable($chapterid, 0);  // Chapter ID
-//$edit is checked for existence later by isset()
+$id        = required_param('id', PARAM_INT);           // Course Module ID
+$chapterid = optional_param('chapterid', 0, PARAM_INT); // Chapter ID
+$edit      = optional_param('edit', -1, PARAM_BOOL);     // Edit mode
 
 // =========================================================================
 // security checks START - teachers edit; students view
@@ -32,14 +32,11 @@ if (!$book = get_record('book', 'id', $cm->instance)) {
 
 $isteacher = isteacheredit($course->id);
 if ($isteacher) {
-    if (isset($edit)) {
-        $USER->editing = ($edit) ? true : false;
-        $edit = $USER->editing;
-    } else {
-        $edit = isset($USER->editing) ? $USER->editing : false;
+    if($edit!= -1) {
+        $USER->editing = $edit;
     }
 } else {
-    $edit = false;
+    $edit = 0;
 }
 
 if (!$cm->visible and !$isteacher) {
@@ -64,11 +61,10 @@ if ($chapterid == '0') { // go to first chapter if no given
         if ($isteacher) {
             $chapterid = $ch->id;
             break;
-        } else {
-            if (!$ch->hidden) {
-                $chapterid = $ch->id;
-                break;
-            }
+        }
+        if (!$ch->hidden) {
+            $chapterid = $ch->id;
+            break;
         }
     }
 }
@@ -226,9 +222,11 @@ $doimport = ($isteacher and $edit) ? '<font size="-1"> (<a href="import.php?id='
           }
         }
         $content .= $chapter->content;
-        $formatoptions->noclean = true;
+
+        $nocleanoption = new object();
+        $nocleanoption->noclean = true;
         echo '<div class="book_content">';
-        echo format_text($content, FORMAT_HTML, $formatoptions, $course->id);
+        echo format_text($content, FORMAT_HTML, $nocleanoption, $course->id);
         echo '</div>';
         print_simple_box_end();
         /// lower navigation
